from pathlib import Path

from pydantic_settings import BaseSettings


class Settings(BaseSettings):
    # Project settings
    PROJECT_NAME: str = "Todo List API"
    PROJECT_DESCRIPTION: str = "A simple Todo List API built with FastAPI and SQLite"
    PROJECT_VERSION: str = "0.1.0"
    
    # API settings
    API_PREFIX: str = "/api"
    HOST: str = "0.0.0.0"
    PORT: int = 8000
    DEBUG: bool = True
    
    # CORS settings
    CORS_ORIGINS: list[str] = ["*"]
    
    # Database settings
    DB_DIR: Path = Path("/app") / "storage" / "db"
    DATABASE_URL: str = f"sqlite:///{DB_DIR}/db.sqlite"
    
    class Config:
        env_file = ".env"
        case_sensitive = True


settings = Settings()