"""Create todos table

Revision ID: 001
Revises: 
Create Date: 2023-05-21 12:00:00.000000

"""
from collections.abc import Sequence
from typing import Union

import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision: str = '001'
down_revision: Union[str, None] = None
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    op.create_table(
        'todos',
        sa.Column('id', sa.Integer(), nullable=False),
        sa.Column('title', sa.String(length=100), nullable=False),
        sa.Column('description', sa.Text(), nullable=True),
        sa.Column('completed', sa.Boolean(), nullable=True, default=False),
        sa.Column(
            'created_at', 
            sa.DateTime(timezone=True), 
            server_default=sa.text('(CURRENT_TIMESTAMP)'), 
            nullable=True
        ),
        sa.Column(
            'updated_at', 
            sa.DateTime(timezone=True), 
            server_default=sa.text('(CURRENT_TIMESTAMP)'), 
            nullable=True
        ),
        sa.PrimaryKeyConstraint('id')
    )
    op.create_index(op.f('ix_todos_id'), 'todos', ['id'], unique=False)


def downgrade() -> None:
    op.drop_index(op.f('ix_todos_id'), table_name='todos')
    op.drop_table('todos')